pywurfl.algorithms.wurfl.handlers.SamsungMatcher

Package pywurfl :: Package algorithms :: Package wurfl :: Module handlers :: Class SamsungMatcher |
[hide private]
[frames] | no frames]

# Class SamsungMatcher

source code

         object --+
                  |
    AbstractMatcher --+
                      |
                     SamsungMatcher

Instance Methods | [hide private]
can_handle(self, user_agent) | source code
find_matching_ua(self, user_agent) | source code
Inherited from `AbstractMatcher`: `__call__`, `__init__`, `add`, `catch_all_recovery_match`, `conclusive_match`, `ld_matcher`, `recovery_match`, `ris_matcher` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Class Variables | [hide private]
| SAMSUNGS = ``[``u'``SEC-``'``,` `u'``SAMSUNG-``'``,` `u'``SCH``'``,` `u'``Samsung``'``,` `u'``SPH``'``,` `...``
Inherited from `AbstractMatcher`: `recovery_map`, `user_agent_map`

Properties | [hide private]
Inherited from `AbstractMatcher`: `user_agents` Inherited from `object`: `__class__`

Method Details | [hide private]

### can_handle(self, user_agent) | source code
Overrides: AbstractMatcher.can_handle

### find_matching_ua(self, user_agent) | source code
Overrides: AbstractMatcher.find_matching_ua

Class Variable Details | [hide private]

  ### SAMSUNGS Value:
      [u'SEC-',
       u'SAMSUNG-',
       u'SCH',
       u'Samsung',
       u'SPH',
       u'SGH',
       u'SAMSUNG/']